@@ -134,7 +134,11 @@ void oer_debug(int level, const char *fmt, ...)
 			   check for errors */
 			mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str_debug, stringbuffer, strlen(stringbuffer));
 			snprintf(query, WRITE_BUFFER_LENGTH, "INSERT INTO oer_output VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str_debug);
-			mysql_query(&mystate->mysqldb.mysqldbconn, query);
+			/* Use mysql_ping() to check that the database is alive, this is
+			   because MySQL doesn't have proper timeouts */
+			if(!mysql_ping(&mystate->mysqldb.mysqldbconn)) {
+				mysql_query(&mystate->mysqldb.mysqldbconn, query);
+			}
 		}
 		if(do_console) {
 			fprintf(stdout, "%s\n", stringbuffer);
@@ -157,6 +161,11 @@ int oer_doquery(char *function, int level, const char *fmt, ...)
 	oer_debug(level, "oer_doquery->%s\n", stringbuffer);
 #endif
 	gettimeofday(&tv1, NULL);
+	/* Use mysql_ping() to check that the database is alive, this is
+	   because MySQL doesn't have proper timeouts */
+        if(mysql_ping(&mystate->mysqldb.mysqldbconn)) {
+		return 0;
+	}
 	if(mysql_query(&mystate->mysqldb.mysqldbconn, stringbuffer)) {
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_FATAL, "%s->mysql_query() failed: %s\n", function, mysql_error(&mystate->mysqldb.mysqldbconn));
