@@ -221,16 +221,18 @@ int serverconnection()
 	memset(&servaddr, 0, sizeof(struct sockaddr_in));
 	servaddr.sin_family = AF_INET;
 	servaddr.sin_addr.s_addr = INADDR_ANY;
-	/* if we don't have a vhost, just use the default system hostname */
-	if(!mystate->vhost) {
-		if(gethostname(mystate->host, HOSTLEN) < 0) {
+	/* get system hostname */
+        if(gethostname(mystate->host, HOSTLEN) < 0) {
 #ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
 #endif
-			close(mystate->sockfd);
-			return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
-		}
-	}
+                close(mystate->sockfd);
+                return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
+        }
+        if(strlen(mystate->vhost)) {
+                /* override with virtual host */
+                strncpy(mystate->host, mystate->vhost, HOSTLEN);
+        }
 	if((hptr = (struct hostent *) gethostbyname(mystate->host)) == NULL) {
 #ifndef _NO_H_ERRNO
 #ifdef DEBUG
@@ -256,7 +258,7 @@ int serverconnection()
 #endif
 	}
 	memcpy((char *) &servaddr.sin_addr, hptr->h_addr, hptr->h_length);
-	if(mystate->vhost) {
+	if(strlen(mystate->vhost)) {
 		/* bind is only necessary for vhost */
 		if(bind(mystate->sockfd, (struct sockaddr *) &servaddr, sizeof(struct sockaddr)) < 0) {
 #ifdef DEBUG
