@@ -265,7 +265,7 @@ enum OER_FLAGS_TYPE {
 #define OER_FLAGS_GLOBAL "dfglmnopqs"
 #define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
-#define OER_FLAGS_USER "!adfmovrsx"
+#define OER_FLAGS_USER "!adfmnovrsx"
 
 #define numofparams(x) (wordcount(x) - 1)
 
@@ -360,16 +360,17 @@ enum OER_FLAGS_TYPE {
 #define IDENTLEN NICKLEN
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
 #define OER_MAX_LIST_LINES 5
-#define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
+#define OER_HELP "For the oer+MySQL user manual go to http://oer.equnet.org/um.php"
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define DEFAULT_WORDBK_MESSAGE "word ban-kick triggered, have a nice life..."
 #define DBSTATUS_MSG "At least one of the executed database queries failed, more \
 details possibly available on the oer+MySQL console"
-#define OER_REALNAME "http://oer.equnet.org/help.html"
+#define OER_REALNAME "http://oer.equnet.org"
 #define OER_UNKNOWN "unknown"
-#define OER_COPYRIGHT1 "oer+MySQL version 1.0-36, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_VERSION "oer+MySQL version 1.0-37"
+#define OER_COPYRIGHT1 "Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer+MySQL comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -627,8 +628,8 @@ struct state {
 	char prefix[TINYSTRINGLEN + 1];
 	char state[STRINGLEN + 1];
 	char proxysetup[STRINGLEN + 1];
+        char vhost[HOSTLEN + 1];
 	int customuser;
-	int vhost;
 	int use_altnick;
 	int sockfd;
 	int loopforever;
