@@ -133,7 +133,7 @@ int main(int argc, char *argv[])
 		oer_debug(OER_DEBUG_INFO, "usage: %s [-a <ident>] [-c] [-d <level>] [-f <config>] [-h] [-s] [-u <ident>] [-t <state>] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	}
-	oer_debug(OER_DEBUG_INFO, "%s\n\n", OER_COPYRIGHT1);
+	oer_debug(OER_DEBUG_INFO, "%s, %s\n\n", OER_VERSION, OER_COPYRIGHT1);
 	oer_debug(OER_DEBUG_INFO, "%s\n", OER_COPYRIGHT2);
 	if(do_version) {
 		exit(EXIT_SUCCESS);
@@ -148,20 +148,20 @@ int main(int argc, char *argv[])
         sigemptyset(&act.sa_mask);
         act.sa_flags = SA_RESTART;
         act.sa_handler = handlesignal;
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGINT, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGINT: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGTERM, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGTERM: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGPIPE, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGPIPE: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGUSR1, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGUSR1: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
 #else
@@ -177,6 +177,10 @@ int main(int argc, char *argv[])
                 oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGPIPE: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
+	if(signal(SIGUSR1, handlesignal) == SIG_ERR) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGUSR1: %s\n", strerror(errno));
+                exit(EXIT_FAILURE);
+        }
 #endif
 	if((mystate = emptystate()) == NULL) {
 		oer_debug(OER_DEBUG_FATAL, "main->failed to allocate memory for irc state\n");
@@ -313,21 +317,27 @@ static void handlesignal(int signal)
 #ifdef DEBUG
         oer_debug(OER_DEBUG_NOISE, "handlesignal(%d)\n", signal);
 #endif
-	if(signal == SIGINT || signal == SIGTERM) {
+	switch(signal) {
+	case SIGINT:
+	case SIGTERM:
 		if(do_signals) {
 			snprintf(mystate->signoff, STRINGLEN, "received %s, leaving for now but I will return!", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
 			quit();
-			return;
-			
 		} else {
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "handlesignal->%s received, ignoring (do_signals = 0)\n", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
 #endif
 		}
-	}
-	if(signal == SIGPIPE) {
+		break;
+	case SIGPIPE:
 		mystate->reconnect = OER_RECONNECT_ERROR;
 		strncpy(mystate->signoff, "received SIGPIPE, connecting to next server", STRINGLEN);
-		return;
+		break;
+	case SIGUSR1:
+                do_debug = (do_debug < OER_DEBUG_FLOOD) ? do_debug + 1 : OER_DEBUG_NONE;
+#ifdef DEBUG
+                oer_debug(OER_DEBUG_NONE, "handlesignal->SIGUSR1 received, new debug level is %d\n", do_debug);
+#endif
+		break;
 	}
 }
