@@ -279,7 +279,7 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     BOTFLAGS=$ans
     readln "Please specify command prefix [!] " "!"
     PREFIX=$ans
-    readln "Please specify IRC REALNAME [http://oer.equnet.org/help.html] " "http://oer.equnet.org/help.html"
+    readln "Please specify IRC REALNAME [http://oer.equnet.org] " "http://oer.equnet.org"
     REALNAME=$ans
     readln "Please specify optional virtual host [] " ""
     VIRTHOST=$ans
@@ -329,7 +329,7 @@ if [ "$CREATECONF" = "y" -o "$CREATECONF" = "Y" ]; then
     PORT=$ans
     readln "Please specify amount of allowed server modes [6] " "6"
     MODES=$ans
-    readln "Please specify ping frequency in seconds on $SERVER [90] " "90"
+    readln "Please specify ping frequency in seconds on $SERVER [120] " "120"
     PINGFREQ=$ans
     readln "Please specify whether IRC operators are protected on $SERVER (0 = no, 1 = yes) [0] " "0"
     PROT=$ans
